@@ -169,5 +169,6 @@ EDITOR_UPDATE_SCHEMA = Schema({
                 })
             ]
         })
-    ]
+    ],
+    Required('show_rubric_during_response', default=False): bool,
 })
